@@ -9,9 +9,11 @@
 #' @param fraction Fraction of data used at each of the \code{B} sub-samples
 #' @param lambda lambda values for group lasso. If not provided, the function generates its own values of lambda
 #' @param hc output of \code{\link{hclust}} function. If not provided, \code{\link{hclust}} is run with ward.D2 method
-#' @param weightLevel a vector of size p for each level of the hierarchy. A zero indicates that the level will be ignored. If not provided, use 1/(height between 2 successive levels)
+#' @param weightLevel a vector of size p for each level of the hierarchy. A zero indicates that the level will be ignored. 
+#' If not provided, use 1/(height between 2 successive levels)
 #' @param weightSizeGroup a vector
-#' @param loss a character string specifying the loss function to use, valid options are: "ls" least squares loss (regression) and "logit" logistic loss (classification)
+#' @param loss a character string specifying the loss function to use, valid options are: "ls" least squares loss 
+#' (regression) and "logit" logistic loss (classification)
 #' @param intercept should an intercept be included in the model ?
 #' @param verbose print some informations
 #' @param ... Others parameters for \code{\link{gglasso}} function
@@ -26,7 +28,8 @@
 #' \item{time}{computation time}
 #' }
 #'
-#' @references Meinshausen and Buhlmann (2010). Stability selection. Journal of the Royal Statistical Society: Series B (Statistical Methodology) 72.4, p. 417-473.
+#' @references Meinshausen and Buhlmann (2010). Stability selection. 
+#' Journal of the Royal Statistical Society: Series B (Statistical Methodology) 72.4, p. 417-473.
 #'
 #' @details
 #' Hierarchical clustering is performed with all the variables. Then, the partitions from the different
@@ -48,7 +51,8 @@
 #' @seealso \link{cv.MLGL}, \link{MLGL}
 #'
 #' @export
-stability.MLGL <- function(X, y, B = 50, fraction = 0.5, hc = NULL, lambda = NULL, weightLevel = NULL, weightSizeGroup = NULL, loss = c("ls", "logit"), intercept = TRUE, verbose = FALSE, ...) {
+stability.MLGL <- function(X, y, B = 50, fraction = 0.5, hc = NULL, lambda = NULL, weightLevel = NULL, 
+                           weightSizeGroup = NULL, loss = c("ls", "logit"), intercept = TRUE, verbose = FALSE, ...) {
 
   # check parameters
   loss <- match.arg(loss)
@@ -132,7 +136,8 @@ stability.MLGL <- function(X, y, B = 50, fraction = 0.5, hc = NULL, lambda = NUL
     testind <- sample(1:n, floor(n * fraction))
 
     t2 <- proc.time()
-    res <- gglasso(Xb[testind, ], y[testind], prelim$group, lambda = lambda, pf = prelim$weight, intercept = intercept, loss = loss, ...)
+    res <- gglasso(Xb[testind, ], y[testind], prelim$group, lambda = lambda, pf = prelim$weight, 
+                   intercept = intercept, loss = loss, ...)
     t3 <- proc.time()
 
     # record selected groups
